@@ -25,6 +25,24 @@ def get_note_title(note):
     else:
         return ''
 
+def get_note_title_file(note):
+    mo = note_title_re.match(note.get('content', ''))
+    if mo:
+        fn = mo.groups()[0]
+        fn = fn.replace(' ', '_')
+        fn = fn.replace('/', '_')
+        if not fn:
+            return ''
+
+        if note_markdown(note):
+            fn += '.mkdn'
+        else:
+            fn += '.txt'
+
+        return fn
+    else:
+        return ''
+
 def human_date(timestamp):
     """
     Given a timestamp, return pretty human format representation.
@@ -65,6 +83,17 @@ def note_pinned(n):
     else:
         return 0
 
+def note_markdown(n):
+    asystags = n.get('systemtags', 0)
+    # no systemtag at all
+    if not asystags:
+        return 0
+
+    if 'markdown' in asystags:
+        return 1
+    else:
+        return 0
+
 tags_illegal_chars = re.compile(r'[\s]')
 def sanitise_tags(tags):
     """
@@ -79,7 +108,14 @@ def sanitise_tags(tags):
     # hack out all kinds of whitespace, then split on ,
     # if you run into more illegal characters (simplenote does not want to sync them)
     # add them to the regular expression above.
-    return tags_illegal_chars.sub('', tags).split(',')
+    illegals_removed = tags_illegal_chars.sub('', tags)
+    if len(illegals_removed) == 0:
+        # special case for empty string ''
+        # split turns that into [''], which is not valid
+        return []
+
+    else:
+        return illegals_removed.split(',')
 
 
 
